@@ -16,9 +16,11 @@ settings = Dynaconf(
     # Load the default settings file
     settings_files=[
         os.path.join(ROOT, "default_settings.toml"),
-        'talky_settings.toml',
-        'settings.toml',
-        '.secrets.toml'
+        # experiment
+        "myllm_settings.toml",
+        "talky_settings.toml",
+        "settings.toml",
+        ".secrets.toml",
     ],
     # Load the.env file
     load_dotenv=True,
@@ -27,5 +29,5 @@ settings = Dynaconf(
     # Set the environments to True
     environments=True,
     # Set the default environment
-    default_env="default",)
-    
+    default_env="default",
+)
